<?php
// $Id: hansel.switches.inc,v 1.1 2010/04/20 20:06:35 mauritsl Exp $

/**
 * @file
 * Hansel switches
 *
 * Switches from Hansel core are located in this file.
 * The definitions resides in hansel.module
 *
 * @see hansel_hansel_switch_types()
 */

/**
 * Callback for "url argument" switch to compare a given value.
 *
 * @param array $arguments
 * @param string $value
 * @return boolean
 */
function hansel_switch_url_argument_compare($arguments, $value) {
  if (empty($arguments['argument'])) {
    $arg = hansel_arg(0);
  }
  else {
    $arg = hansel_arg(((int) $arguments['argument']) - 1);
  }
  return $arg == $value;
}

/**
 * Callback for "url argument" switch to generate the information line.
 *
 * @param array $arguments
 * @return string
 */
function hansel_switch_url_argument_info($arguments) {
  if (empty($arguments)) {
    return '1';
  }
  return $arguments['argument'];
}

/**
 * Callback for "url argument" switch to generate the configuration form.
 *
 * @param array $arguments
 * @return array
 */
function hansel_switch_url_argument_config_form($arguments) {
  $form = array();
  
  $form['argument'] = array(
    '#type' => 'textfield',
    '#title' => t('Argument number'),
    '#default_value' => empty($arguments['argument']) ? '1' : $arguments['argument'],
    '#size' => 5,
    '#description' => t('Must be numeric. Use 1 for the first argument.'),
    '#required' => TRUE,
  );
  
  $form['#validate'] = array('hansel_switch_url_arguments_config_form_validate');
  
  return hansel_switch_configure_form($form);
}

/**
 * Validate callback for the "url argument" switch configuration form.
 */
function hansel_switch_url_arguments_config_form_validate($form, &$form_state) {
  if (!preg_match('/^[1-9][0-9]?$/', $form_state['values']['argument'])) {
    form_set_error('argument', t('Argument must be a number between 1 and 99'));
  }
}

/**
 * Callback for "node id" switch to compare a given value.
 *
 * @param array $arguments
 * @param string $value
 * @return boolean
 */
function hansel_switch_node_id_compare($arguments, $value) {
  if (hansel_arg(0) == 'node' && is_numeric(hansel_arg(1))) {
    return hansel_arg(1) == $value;
  }
  return FALSE;
}

/**
 * Callback for "node id" switch to compare a given value.
 *
 * @param array $arguments
 * @param string $value
 * @return boolean
 */
function hansel_switch_node_type_compare($arguments, $value) {
  if (hansel_arg(0) == 'node' && is_numeric(hansel_arg(1))) {
    if ($node = node_load(hansel_arg(1))) {
      return $node->type == $value;
    }
  }
  return FALSE;
}
